QueuedCheckpointVerified

Type Alias QueuedCheckpointVerified 

pub type QueuedCheckpointVerified = (CheckpointVerifiedBlock, Sender<Result<Hash, CommitCheckpointVerifiedError>>);
A queued checkpoint verified block, and its corresponding Result channel.

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 136 bytes